/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.column;

import java.util.Locale;
import java.util.Map;
import java.util.HashMap;

import org.opengion.hayabusa.db.AbstractRenderer;
import org.opengion.hayabusa.db.CellRenderer;
import org.opengion.hayabusa.db.DBColumn;

/**
 * ICON レンデラーは、カラムのファイル名の拡張子からアイコンファイルのイメージタグを作成します。
 * イメージデータは、jsp/image/thumb を使用します。
 *
 * 実質的には、アイコンではなく、サムネイルとして利用します。
 * 
 * 縦横比をそのままに、縦か横の最大値に画像サイズを合わせるには、
 * style="max-width:100; max-height:100;" をセットすることで対応できます。
 * class="ICON" 属性を出力しておきますので、CSSファイルで記述してください。
 *
 * (例：)
 *<pre>
 *  &lt;style type="text/css"&gt;
 *      img.ICON { max-width:100px; max-height:100px; }
 *  &lt;/style&gt;
 *</pre>
 *
 * このクラスは、不変オブジェクトとして、共有されます。
 *
 * @og.rev 5.6.5.1 (2013/06/14) 新規作成
 *
 * @og.group データ表示
 *
 * @version  4.0
 * @author	 Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class Renderer_ICON extends AbstractRenderer {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "5.6.5.1 (2013/06/14)" ;

	private static final CellRenderer dbCell = new Renderer_ICON() ;

	// アイコンファイルに割り当てられる拡張子とファイルの関連(MAP)情報
	private static final Map<String,String> ICON_MAP ;
	static {
		ICON_MAP = new HashMap<String,String>();

		ICON_MAP.put( "doc"		,	"../image/thumb/doc.png" );
		ICON_MAP.put( "docx"	,	"../image/thumb/doc.png" );
		ICON_MAP.put( "xls"		,	"../image/thumb/xls.png" );
		ICON_MAP.put( "xlsx"	,	"../image/thumb/xls.png" );
		ICON_MAP.put( "ppt"		,	"../image/thumb/ppt.png" );
		ICON_MAP.put( "pptx"	,	"../image/thumb/ppt.png" );
		ICON_MAP.put( "pdf"		,	"../image/thumb/pdf.png" );
		ICON_MAP.put( "txt"		,	"../image/thumb/text.png" );
		ICON_MAP.put( "zip"		,	"../image/thumb/zip.png" );
	}
	private static final String DOC_VIEW = "../image/thumb/docview.png" ;		// その他のアイコン

	/**
	 * 各オブジェクトから自分のインスタンスを返します。
	 * 自分自身をキャッシュするのか、新たに作成するのかは、各サブクラスの実装に
	 * まかされます。
	 *
	 * @param	clm	DBColumnオブジェクト
	 *
	 * @return	CellRendererオブジェクト
	 */
	public CellRenderer newInstance( final DBColumn clm ) {
		return dbCell;
	}

	/**
	 * データの表示用文字列を返します。
	 *
	 * @param	value 入力値
	 *
	 * @return	データの表示用文字列
	 */
	@Override
	public String getValue( final String value ) {
		String icon = null;

		if( value != null ) {
			String sufix = null;
			int idx = value.lastIndexOf(".");
			if( idx >= 0 ) {
				sufix = value.substring( idx+1 ).toLowerCase( Locale.JAPAN );
				icon = ICON_MAP.get( sufix );
			}
		}

		if( icon == null ) { icon = DOC_VIEW; }

		return "<img class=\"ICON\" src=\"" + icon + "\" alt=\"" + value + "\" />" ;
	}
}
